EasyExtend.langlets.p4d.p4dutils.p4dprinter

Package EasyExtend :: Package langlets :: Package p4d :: Module p4dutils :: Class p4dprinter |
[hide private]
[frames] | no frames]

# Class p4dprinter

    object --+
             |
      pprinter --+
                 |
                p4dprinter

Instance Methods | [hide private]
check_tag(self, tag, convert_kwd=False, prefixed=`set([``])`) |
pprint(self, prefix_keyword=False) |
formatText(self, S, level, comment=False, double_comment=False) |
formatAttributes(self, attr, elem, level, prefix_keyword, prefixed) |
Inherited from `pprinter`: `__init__`, `walker` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`